GWpy is a collaboration-driven Python package providing tools for
studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface to the common
time-domain and frequency-domain data produced by the LIGO and Virgo
observatories and their analyses, with easy-to-follow tutorials at each
step.

https://gwpy.github.io

Release status
~~~~~~~~~~~~~~

|PyPI version| |DOI| |License| |Supported Python versions| |Research
software impact|

|Build Status| |Coverage Status| |Code Health|

Development status
~~~~~~~~~~~~~~~~~~

|Build Status dev| |Coverage Status dev| |Code Health dev| |Maintainability|

Installation
~~~~~~~~~~~~

To install, you can do:

::

    pip install gwpy

You can test your installation, and its version by

::

    python -c "import gwpy; print(gwpy.__version__)"


.. |PyPI version| image:: https://badge.fury.io/py/gwpy.svg
   :target: http://badge.fury.io/py/gwpy
.. |DOI| image:: https://zenodo.org/badge/9979119.svg
   :target: https://zenodo.org/badge/latestdoi/9979119
.. |License| image:: https://img.shields.io/pypi/l/gwpy.svg
   :target: https://choosealicense.com/licenses/gpl-3.0/
.. |Supported Python versions| image:: https://img.shields.io/pypi/pyversions/gwpy.svg
   :target: https://travis-ci.org/gwpy/gwpy
.. |Research software impact| image:: http://depsy.org/api/package/pypi/gwpy/badge.svg
   :target: http://depsy.org/package/python/gwpy
.. |Build Status| image:: https://travis-ci.org/gwpy/gwpy.svg?branch=master
   :target: https://travis-ci.org/gwpy/gwpy
.. |Coverage Status| image:: https://coveralls.io/repos/github/gwpy/gwpy/badge.svg?branch=master
   :target: https://coveralls.io/github/gwpy/gwpy?branch=master
.. |Code Health| image:: https://landscape.io/github/gwpy/gwpy/master/landscape.svg?style=flat
   :target: https://landscape.io/github/gwpy/gwpy/master
.. |Build Status dev| image:: https://travis-ci.org/gwpy/gwpy.svg?branch=develop
   :target: https://travis-ci.org/gwpy/gwpy
.. |Coverage Status dev| image:: https://coveralls.io/repos/github/gwpy/gwpy/badge.svg?branch=develop
   :target: https://coveralls.io/github/gwpy/gwpy?branch=develop
.. |Code Health dev| image:: https://landscape.io/github/gwpy/gwpy/develop/landscape.svg?style=flat
   :target: https://landscape.io/github/gwpy/gwpy/develop
.. |Maintainability| image:: https://api.codeclimate.com/v1/badges/2cf14445b3e070133745/maintainability
   :target: https://codeclimate.com/github/gwpy/gwpy/maintainability
